@@ -7,7 +7,7 @@ from .device import Device
 from .hub import Hub, CannotConnectError, ProgrammingError, NotConnectedError
 from .metric import Metric
 from .switch import Switch
-from ._victron_enums import DeviceType, InverterState, InverterMode, GenericOnOff, EvChargerMode, InverterOverloadAlarmEnum, FluidType, TemperatureType, TemperatureStatus, SolarChargerState, ESSMode, MultiState
+from ._victron_enums import DeviceType, InverterState, InverterMode, GenericOnOff, EvChargerMode, InverterOverloadAlarmEnum, FluidType, TemperatureType, TemperatureStatus, SolarChargerState, ESSMode, MultiState, DESSReactiveStrategy, DESSStrategy, DESSErrorCode, DESSRestrictions, VictronDeviceEnum
 
 __all__ = [
     "Hub",
@@ -33,5 +33,10 @@ __all__ = [
     "FluidType",
     "SolarChargerState",
     "ESSMode",
-    "MultiState"
+    "MultiState",
+    "DESSReactiveStrategy",
+    "DESSStrategy",
+    "DESSErrorCode",
+    "DESSRestrictions",
+    "VictronDeviceEnum",
 ]
