@@ -1,7 +1,7 @@
 """Constants for the victron venus OS client."""
 
 from enum import Enum
-from typing import TypeVar, cast
+from typing import Self
 
 TOPIC_INSTALLATION_ID = "N/+/system/0/Serial"
 
@@ -31,6 +31,7 @@ class MetricType(Enum):
 
     NONE = "none"
     POWER = "power"
+    APPARENT_POWER = "apparent_power"
     ENERGY = "energy"
     VOLTAGE = "voltage"
     CURRENT = "current"
@@ -40,6 +41,7 @@ class MetricType(Enum):
     TIME = "time"
     PERCENTAGE = "percentage"
     ELECTRIC_STORAGE_CAPACITY = "electric_storage_capacity"
+    ELECTRIC_STORAGE_PERCENTAGE = "electric_storage_percentage"
     LIQUID_VOLUME = "liquid_volume"
     LOCATION = "location"
     HEADING = "heading"
@@ -66,7 +68,6 @@ class RangeType(Enum):
 PLACEHOLDER_PHASE = "{phase}"
 PLACEHOLDER_NEXT_PHASE = "{next_phase}"
 
-T = TypeVar("T", bound="VictronEnum")
 class VictronEnum(Enum):
     def __init__(self, code, string):
         self._value_ = (code, string)
@@ -86,10 +87,10 @@ class VictronEnum(Enum):
         return cls._lookup_by_code
 
     @classmethod
-    def from_code(cls: type[T], value: int | str, default_value: T | None = None) -> T | None:
+    def from_code(cls: type[Self], value: int | str, default_value: "VictronEnum | None" = None) -> Self | None:
         lookup = cls._build_code_lookup()
         result = lookup.get(value, default_value)
-        return cast(T, result) if result is not None else None
+        return result  # type: ignore[return-value]
 
     @classmethod
     def _build_string_lookup(cls):
@@ -98,7 +99,7 @@ class VictronEnum(Enum):
         return cls._lookup_by_string
 
     @classmethod
-    def from_string(cls, value: str):
+    def from_string(cls: type[Self], value: str) -> Self:
         lookup = cls._build_string_lookup()
         try:
             return lookup[value]
@@ -109,3 +110,17 @@ class VictronDeviceEnum(VictronEnum):
     def __init__(self, code: str, string: str, mapped_to: str | None = None):
         super().__init__(code, string)
         self.mapped_to = mapped_to
+
+    @classmethod
+    def from_code(cls: type[Self], value: int | str, default_value: "VictronDeviceEnum | None" = None) -> "VictronDeviceEnum | None":
+        result = super().from_code(value, default_value)
+        if result is None:
+            return None
+        assert isinstance(result, VictronDeviceEnum)
+        if result.mapped_to:
+            mapped_result = super().from_code(result.mapped_to, default_value)
+            if mapped_result is None:
+                return None
+            assert isinstance(mapped_result, VictronDeviceEnum)
+            result = mapped_result
+        return result
